@@ -85,7 +85,7 @@
 estimateSimpleSBM <- function(netMat,
                               model        = 'bernoulli',
                               directed     = !isSymmetric(netMat),
-                              dimLabels    = c(node = "nodeName"),
+                              dimLabels    = c("node"),
                               covariates   = list(),
                               estimOptions = list()) {
 
@@ -138,7 +138,7 @@ estimateSimpleSBM <- function(netMat,
 #'  \item{"plot"}{boolean, should the ICL by dynamically plotted or not. Default is TRUE}
 #'  \item{"exploreFactor"}{control the exploration of the number of groups}
 #'  \item{"exploreMin"}{explore at least until exploreMin even if the exploration factor rule is achieved. Default 4. See the package blockmodels for details.}
-#'  \item{"exploreMin"}{Stop exploration at exploreMax  even if the exploration factor rule is not achieved. Default Inf. See the package blockmodels for details.}
+#'  \item{"exploreMax"}{Stop exploration at exploreMax  even if the exploration factor rule is not achieved. Default Inf. See the package blockmodels for details.}
 #'  \item{"fast"}{logical: should approximation be used for Bernoulli model with covariates. Default to \code{TRUE}}
 #' }
 #' @return  a list with the estimated parameters. See details...
